##  Configuring Field Mappings
After setting up a fact sheet mapping, you can configure field mappings for it.
Follow these steps:
  1. Hover over a fact sheet mapping, then click Configuration under Field Mapping.
![Navigating to Field Mapping Configuration](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274f66f17a441014a1a4c9fc744953e8_LowRes.png)
Navigating to Field Mapping Configuration
  2. On the field mapping page, add mappings by clicking Add Fields, then configure mapping parameters. For more information on each parameter, refer to the following sections in this topic.
  3. If relevant, set up matching rules to define how the integration identifies matching items. For more information, see [Matching Rules](https://help.sap.com/docs/leanix/ea/matching-rules?locale=en-US&state=PRODUCTION&version=CLOUD "Set up rules for matching fact sheets between ServiceNow and SAP LeanIX during the initial synchronization.").
![Configuring Field Mappings for a Fact Sheet](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274c3ee47a441014a5b6b1f8f199b26f_LowRes.png)
Configuring Field Mappings for a Fact Sheet
  4. Save your changes.
